#
# Ronin Web - A Ruby library for Ronin that provides support for web
# scraping and spidering functionality.
#
# Copyright (c) 2006-2009 Hal Brodigan (postmodern.mod3 at gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

require 'ronin/web/server/helpers/files'

module Ronin
  module Web
    module Server
      module Files
        def self.included(base)
          base.module_eval do
            #
            # Hosts the contents of a file.
            #
            # @param [String] http_path
            #   The path the web server will host the file at.
            #
            # @param [String] path
            #   The path to the local file.
            #
            # @param [Symbol] custom_content_type
            #   Optional content-type to host the file as.
            #
            # @example
            #   MyApp.file '/robots.txt', '/path/to/my_robots.txt'
            #
            # @since 0.2.0
            #
            def self.file(http_path,path,custom_content_type=nil)
              path = File.expand_path(path)

              any(http_path) do
                return_file(path,custom_content_type)
              end
            end

            #
            # Hosts the contents of the directory.
            #
            # @param [String] http_path
            #   The path the web server will host the directory at.
            #
            # @param [String] directory
            #   The path to the local directory.
            #
            # @param [Symbol] custom_content_type
            #   Optional content-type to host the contents of the directory
            #   with.
            #
            # @example
            #   MyApp.directory '/download/', '/tmp/files/'
            #
            # @since 0.2.0
            #
            def self.directory(http_path,directory,custom_content_type=nil)
              directory = File.expand_path(directory)

              any(File.join(http_path,'*')) do
                sub_path = File.expand_path(File.join('',params[:splat].first))
                full_path = File.join(directory,sub_path)

                return_file(full_path,custom_content_type)
              end
            end

            protected

            helpers Ronin::Web::Server::Helpers::Files
          end
        end
      end
    end
  end
end
